@@ -14,6 +14,7 @@
 #include <ctype.h>
 #include <ncurses.h>
 #include <errno.h>
+#include <time.h>
 
 #define RXBUFFSIZE 1024
 #define TXWINHEIGHT 3
@@ -51,7 +52,7 @@ static void del_char(char *, char *);
 static void status(int, const char *, int, int, int);
 static int my_wclear(WINDOW *);
 
-static char *Version = "ColrConv v0.99.2";
+static char *Version = "ColrConv v0.99.3";
 
 static int HasColors = 0;
 static int NoColor   = 0;
@@ -95,6 +96,7 @@ int main(int argc, char *argv[])
     char *cp;			/* Temp char pointer */
     int nextarg;
     FILE *f;			/* ~/.conversrc */
+    char ch;
 
     Name = getlogin();
 
@@ -286,11 +288,8 @@ int main(int argc, char *argv[])
 	FD_SET(STDIN_FILENO,&read_fdset); 
 	timeout.tv_sec = 1;	/* paranoid timer */
 	timeout.tv_usec = 0;
-	/* Why does numfds have to be 4? */
-	/* According to to sunos manual, correct value can be obtained */
-	/* from ulimit(), but this is currently unimplimented in linux. */
 	/* Wake me if something happens */
-	if(select(4,&read_fdset,0,0,&timeout) == -1) {
+	if(select(sockfd+1,&read_fdset,0,0,&timeout) == -1) {
 	    if(errno != EINTR) {
 		echo();
 		nocbreak();
@@ -303,7 +302,8 @@ int main(int argc, char *argv[])
 	    }
 	}
 	/* Check for receive data */
-	while((recvretval = recv(sockfd,&c,1,0)) != -1){ 
+	while((recvretval = recv(sockfd,&ch,1,0)) != -1){ 
+            c = ch;
 	    /* one byte at a time so we can strip chars */
 	    if(recvretval == 0) { /* Socket disconnected */
 		echo();
